aboutsummaryrefslogtreecommitdiff
path: root/documentation/examples
diff options
context:
space:
mode:
Diffstat (limited to 'documentation/examples')
-rw-r--r--documentation/examples/hooks/register/advanced.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/documentation/examples/hooks/register/advanced.php b/documentation/examples/hooks/register/advanced.php
index a21a2e232..627bb5454 100644
--- a/documentation/examples/hooks/register/advanced.php
+++ b/documentation/examples/hooks/register/advanced.php
@@ -1,6 +1,6 @@
<?php
// the output:page hook is triggered by page_draw().
register_plugin_hook('output', 'page', 'example_plugin_hook_handler', 600);
register_plugin_hook('output', 'page', 'example_plugin_hook_handler_2', 601);
@@ -11,7 +11,7 @@ function example_plugin_hook_handler($event, $type, $value, $params) {
return $value;
}
-function example_plugin_hook_handler($event, $type, $value, $params) {
+function example_plugin_hook_handler_2($event, $type, $value, $params) {
// change S to $
$value = str_replace('S', '$', $value);
@@ -20,4 +20,4 @@ function example_plugin_hook_handler($event, $type, $value, $params) {
$content = 'This is some Sample Content.';
-page_draw('Title', $content); \ No newline at end of file
+echo elgg_view_page('Title', $content); \ No newline at end of file
@@ -1,6 +1,6 @@
<?php
-// the output:page hook is triggered by page_draw().
+// the output:page hook is triggered by elgg_view_page().
register_plugin_hook('output', 'page', 'example_plugin_hook_handler', 600);
register_plugin_hook('output', 'page', 'example_plugin_hook_handler_2', 601);